==> haskell-aeson-pretty-0.7.2-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.7.2
id: aeson-pretty-0.7.2-5owwLyZQe1mCwtsylrhEC5
key: aeson-pretty-0.7.2-5owwLyZQe1mCwtsylrhEC5
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: d426c0b11c81790e565126d86ffd2e5f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.7.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-pretty-0.7.2
hs-libraries: HSaeson-pretty-0.7.2-5owwLyZQe1mCwtsylrhEC5
depends:
    aeson-0.11.2.0-KYo3VjEYbuTH5av5CAe0oK base-4.9.0.0
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.7.2-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.7.2
id: aeson-pretty-0.7.2-2apOcItFCoz1yfOHeN0rVA
key: aeson-pretty-0.7.2-2apOcItFCoz1yfOHeN0rVA
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: b41e9e6dda27c8bb1f2d79a843ff5bfc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-pretty-0.7.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-pretty-0.7.2
hs-libraries: HSaeson-pretty-0.7.2-2apOcItFCoz1yfOHeN0rVA
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg base-4.9.0.0
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
